<?php
/**
 * @file
 * Default theme implementation to display a single Drupal page.
 *
 * The doctype, html, head and body tags are not in this template. Instead they
 * can be found in the html.tpl.php template in this directory.
 *
 * Available variables:
 *
 * General utility variables:
 * - $base_path: The base URL path of the Drupal installation. At the very
 *   least, this will always default to /.
 * - $directory: The directory the template is located in, e.g. modules/system
 *   or themes/bartik.
 * - $is_front: TRUE if the current page is the front page.
 * - $logged_in: TRUE if the user is registered and signed in.
 * - $is_admin: TRUE if the user has permission to access administration pages.
 *
 * Site identity:
 * - $front_page: The URL of the front page. Use this instead of $base_path,
 *   when linking to the front page. This includes the language domain or
 *   prefix.
 * - $logo: The path to the logo image, as defined in theme configuration.
 * - $site_name: The name of the site, empty when display has been disabled
 *   in theme settings.
 * - $site_slogan: The slogan of the site, empty when display has been disabled
 *   in theme settings.
 *
 * Navigation:
 * - $main_menu (array): An array containing the Main menu links for the
 *   site, if they have been configured.
 * - $secondary_menu (array): An array containing the Secondary menu links for
 *   the site, if they have been configured.
 * - $breadcrumb: The breadcrumb trail for the current page.
 *
 * Page content (in order of occurrence in the default page.tpl.php):
 * - $title_prefix (array): An array containing additional output populated by
 *   modules, intended to be displayed in front of the main title tag that
 *   appears in the template.
 * - $title: The page title, for use in the actual HTML content.
 * - $title_suffix (array): An array containing additional output populated by
 *   modules, intended to be displayed after the main title tag that appears in
 *   the template.
 * - $messages: HTML for status and error messages. Should be displayed
 *   prominently.
 * - $tabs (array): Tabs linking to any sub-pages beneath the current page
 *   (e.g., the view and edit tabs when displaying a node).
 * - $action_links (array): Actions local to the page, such as 'Add menu' on the
 *   menu administration interface.
 * - $feed_icons: A string of all feed icons for the current page.
 * - $node: The node object, if there is an automatically-loaded node
 *   associated with the page, and the node ID is the second argument
 *   in the page's path (e.g. node/12345 and node/12345/revisions, but not
 *   comment/reply/12345).
 *
 * Regions:
 * - $page['help']: Dynamic help text, mostly for admin pages.
 * - $page['highlighted']: Items for the highlighted content region.
 * - $page['content']: The main content of the current page.
 * - $page['sidebar_first']: Items for the first sidebar.
 * - $page['sidebar_second']: Items for the second sidebar.
 * - $page['header']: Items for the header region.
 * - $page['footer']: Items for the footer region.
 *
 * @see bootstrap_preprocess_page()
 * @see template_preprocess()
 * @see template_preprocess_page()
 * @see bootstrap_process_page()
 * @see template_process()
 * @see html.tpl.php
 *
 * @ingroup themeable
 */
?>
<!-- Static navbar -->
<div id="navbar" class="navbar navbar-default navbar-fixed-top"
     role="navigation">
  <div class="container">
    <div class="navbar-header">
      <button type="button" class="navbar-toggle" data-toggle="collapse"
              data-target=".navbar-collapse">
        <span class="sr-only"><?php print t('Toggle navigation'); ?></span>
        <span class="icon-bar"></span>
        <span class="icon-bar"></span>
        <span class="icon-bar"></span>
      </button>
      <?php if (!empty($site_name)): ?>
        <a class="name navbar-brand" href="<?php print $front_page; ?>"
           title="<?php print t('Home'); ?>"><?php print $site_name; ?></a>
      <?php endif; ?>
    </div>
    <div class="navbar-collapse collapse">
      <?php if (!empty($primary_nav)): ?>
        <?php print render($primary_nav); ?>
      <?php endif; ?>
    </div>
    <!--/.nav-collapse -->
  </div>
</div>

<div id="headerwrap">
  <div class="container">
    <div class="row">
      <div class="col-lg-6 col-lg-offset-3">
        <?php if ($header_box): ?>
          <?php print $header_box; ?>
        <?php endif; ?>
        <?php print render($page['header']); ?>
      </div>
    </div>
    <!--/row -->
  </div>
  <!-- /container -->
</div><!--/headerwrap -->

<?php if ($tabs): ?>
  <div class="container">
    <div class="row centered">
      <div class="tabs"><?php print render($tabs); ?></div>
    </div>
  </div>
<?php endif; ?>

<?php print $messages; ?>

<section id="works"></section>

<div class="container">
  <div class="row centered mt mb">
    <a id="main-content"></a>
    <?php if (empty($title)): ?>
      <h1><?php print t('My Portfolio'); ?></h1>
    <?php endif; ?>

    <?php print render($page['content']); ?>
  </div>
  <!--/row -->
</div><!--/container -->

<?php if (!empty($social_button)): ?>
  <div id="social">
    <div class="container">
      <div class="row centered">
        <?php foreach ($social_button as $name => $url): ?>
          <div class="col-lg-2">
            <a href="<?php print $url ?>" title="<?php print $name; ?>"
               target="_blank"><i class="fa fa-<?php print $name; ?>"></i></a>
          </div>
        <?php endforeach; ?>
      </div>
      <!--/row -->
    </div>
    <!--/container -->
  </div><!--/social -->
<?php endif; ?>

<div id="footerwrap">
  <div class="container">
    <div class="row centered">
      <div class="col-lg-4">
        <?php print render($page['footer_first']); ?>
      </div>

      <div class="col-lg-4">
        <?php print render($page['footer_second']); ?>
      </div>

      <div class="col-lg-4">
        <?php print render($page['footer_third']); ?>
      </div>
    </div>
  </div>
</div><!--/footerwrap -->
